# SpyDir

Directory listing scanner to search for downloadable archives and other files

```bash
# you can use pip instead
pipx install spydir

# scan list of urls
spydir -i urls.txt -o results.txt

# see help
spydir -h
```
